@@ -3,7 +3,7 @@
 /***********************************************************************
 *  This code is part of GLPK (GNU Linear Programming Kit).
 *
-*  Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
+*  Copyright (C) 2000,01,02,03,04,05,06,07,08,2009 Andrew Makhorin,
 *  Department for Applied Informatics, Moscow Aviation Institute,
 *  Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 *
@@ -22,6 +22,7 @@
 ***********************************************************************/
 
 #include "glpapi.h"
+#include "glpini.h"
 
 /***********************************************************************
 *  NAME
@@ -51,11 +52,11 @@
 void glp_set_row_stat(glp_prob *lp, int i, int stat)
 {     GLPROW *row;
       if (!(1 <= i && i <= lp->m))
-         xfault("glp_set_row_stat: i = %d; row number out of range\n",
+         xerror("glp_set_row_stat: i = %d; row number out of range\n",
             i);
       if (!(stat == GLP_BS || stat == GLP_NL || stat == GLP_NU ||
             stat == GLP_NF || stat == GLP_NS))
-         xfault("glp_set_row_stat: i = %d; stat = %d; invalid status\n",
+         xerror("glp_set_row_stat: i = %d; stat = %d; invalid status\n",
             i, stat);
       row = lp->row[i];
       if (stat != GLP_BS)
@@ -105,11 +106,11 @@ void glp_set_row_stat(glp_prob *lp, int i, int stat)
 void glp_set_col_stat(glp_prob *lp, int j, int stat)
 {     GLPCOL *col;
       if (!(1 <= j && j <= lp->n))
-         xfault("glp_set_col_stat: j = %d; column number out of range\n"
+         xerror("glp_set_col_stat: j = %d; column number out of range\n"
             , j);
       if (!(stat == GLP_BS || stat == GLP_NL || stat == GLP_NU ||
             stat == GLP_NF || stat == GLP_NS))
-         xfault("glp_set_col_stat: j = %d; stat = %d; invalid status\n",
+         xerror("glp_set_col_stat: j = %d; stat = %d; invalid status\n",
             j, stat);
       col = lp->col[j];
       if (stat != GLP_BS)
@@ -134,55 +135,88 @@ void glp_set_col_stat(glp_prob *lp, int j, int stat)
 /***********************************************************************
 *  NAME
 *
-*  glp_get_row_stat - retrieve row status
+*  glp_std_basis - construct standard initial LP basis
 *
 *  SYNOPSIS
 *
-*  int glp_get_row_stat(glp_prob *lp, int i);
+*  void glp_std_basis(glp_prob *lp);
 *
-*  RETURNS
+*  DESCRIPTION
 *
-*  The routine glp_get_row_stat returns current status assigned to the
-*  auxiliary variable associated with i-th row as follows:
+*  The routine glp_std_basis builds the "standard" (trivial) initial
+*  basis for the specified problem object.
 *
-*  GLP_BS - basic variable;
-*  GLP_NL - non-basic variable on its lower bound;
-*  GLP_NU - non-basic variable on its upper bound;
-*  GLP_NF - non-basic free (unbounded) variable;
-*  GLP_NS - non-basic fixed variable. */
+*  In the "standard" basis all auxiliary variables are basic, and all
+*  structural variables are non-basic. */
 
-int glp_get_row_stat(glp_prob *lp, int i)
-{     if (!(1 <= i && i <= lp->m))
-         xfault("glp_get_row_stat: i = %d; row number out of range\n",
-            i);
-      return lp->row[i]->stat;
+void glp_std_basis(glp_prob *lp)
+{     int i, j;
+      /* make all auxiliary variables basic */
+      for (i = 1; i <= lp->m; i++)
+         glp_set_row_stat(lp, i, GLP_BS);
+      /* make all structural variables non-basic */
+      for (j = 1; j <= lp->n; j++)
+      {  GLPCOL *col = lp->col[j];
+         if (col->type == GLP_DB && fabs(col->lb) > fabs(col->ub))
+            glp_set_col_stat(lp, j, GLP_NU);
+         else
+            glp_set_col_stat(lp, j, GLP_NL);
+      }
+      return;
 }
 
 /***********************************************************************
 *  NAME
 *
-*  glp_get_col_stat - retrieve column status
+*  glp_adv_basis - construct advanced initial LP basis
 *
 *  SYNOPSIS
 *
-*  int glp_get_col_stat(glp_prob *lp, int j);
+*  void glp_adv_basis(glp_prob *lp, int flags);
 *
-*  RETURNS
+*  DESCRIPTION
 *
-*  The routine glp_get_col_stat returns current status assigned to the
-*  structural variable associated with j-th column as follows:
+*  The routine glp_adv_basis constructs an advanced initial basis for
+*  the specified problem object.
 *
-*  GLP_BS - basic variable;
-*  GLP_NL - non-basic variable on its lower bound;
-*  GLP_NU - non-basic variable on its upper bound;
-*  GLP_NF - non-basic free (unbounded) variable;
-*  GLP_NS - non-basic fixed variable. */
+*  The parameter flags is reserved for use in the future and must be
+*  specified as zero. */
 
-int glp_get_col_stat(glp_prob *lp, int j)
-{     if (!(1 <= j && j <= lp->n))
-         xfault("glp_get_col_stat: j = %d; column number out of range\n"
-            , j);
-      return lp->col[j]->stat;
+void glp_adv_basis(glp_prob *lp, int flags)
+{     if (flags != 0)
+         xerror("glp_adv_basis: flags = %d; invalid flags\n", flags);
+      if (lp->m == 0 || lp->n == 0)
+         glp_std_basis(lp);
+      else
+         adv_basis(lp);
+      return;
+}
+
+/***********************************************************************
+*  NAME
+*
+*  glp_cpx_basis - construct Bixby's initial LP basis
+*
+*  SYNOPSIS
+*
+*  void glp_cpx_basis(glp_prob *lp);
+*
+*  DESCRIPTION
+*
+*  The routine glp_cpx_basis constructs an advanced initial basis for
+*  the specified problem object.
+*
+*  The routine is based on Bixby's algorithm described in the paper:
+*
+*  Robert E. Bixby. Implementing the Simplex Method: The Initial Basis.
+*  ORSA Journal on Computing, Vol. 4, No. 3, 1992, pp. 267-84. */
+
+void glp_cpx_basis(glp_prob *lp)
+{     if (lp->m == 0 || lp->n == 0)
+         glp_std_basis(lp);
+      else
+         cpx_basis(lp);
+      return;
 }
 
 /* eof */
