@@ -3,7 +3,7 @@
 /***********************************************************************
 *  This code is part of GLPK (GNU Linear Programming Kit).
 *
-*  Copyright (C) 2000, 01, 02, 03, 04, 05, 06, 07 Andrew Makhorin,
+*  Copyright (C) 2000,01,02,03,04,05,06,07,08,2009 Andrew Makhorin,
 *  Department for Applied Informatics, Moscow Aviation Institute,
 *  Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 *
@@ -111,7 +111,7 @@ done: if (flag != NULL) xfree(flag);
 -- 2 - the number of columns (n) is negative;
 -- 3 - A_ptr[1] is not 1;
 -- 4 - some column index is out of range;
--- 5 - some column index is duplicate. */
+-- 5 - some column indices are duplicate. */
 
 int check_pattern(int m, int n, int A_ptr[], int A_ind[])
 {     int i, j, ptr, ret, *flag = NULL;
